==> activity-center-api-0.8.9.1-lqs3-20180413.012950-1-sources.jar: cn/com/duiba/tuia/activity/center/api/dto/ExtInfo.java <==
package cn.com.duiba.tuia.activity.center.api.dto;

import java.io.Serializable;

public class ExtInfo implements Serializable {

    private static final long serialVersionUID = -5922021485325753804L;
    /**
     * 现金奖励限制
     */
    private Integer cashLimit;

    /**
     * 积分奖励限制
     */
    private Integer integralLimit;
    /**
     * 每日拼图限制
     */
    private Integer timesLimit;
    /**
     * 拼图投放方式 如果为空或者为0代表小程序，1代表H5版本
     */
    private Integer outputWay;

    /**
     * 押注游戏-普通模式金额
     */
    private Integer normalMode;
    /**
     * 押注游戏-超级模式金额
     */
    private Integer superMode;

    private String ruleConfig;

    private Long pageId;

    /**
     * 首次登陆
     */
    private Long firstGive;

    /**
     * 每日登陆
     */
    private Long dailyGive;

    public Integer getCashLimit() {
        return cashLimit;
    }

    public void setCashLimit(Integer cashLimit) {
        this.cashLimit = cashLimit;
    }

    public Integer getIntegralLimit() {
        return integralLimit;
    }

    public void setIntegralLimit(Integer integralLimit) {
        this.integralLimit = integralLimit;
    }

    public Integer getTimesLimit() {
        return timesLimit;
    }

    public void setTimesLimit(Integer timesLimit) {
        this.timesLimit = timesLimit;
    }

    public String getRuleConfig() {
        return ruleConfig;
    }

    public void setRuleConfig(String ruleConfig) {
        this.ruleConfig = ruleConfig;
    }

    public Long getPageId() {
        return pageId;
    }

    public void setPageId(Long pageId) {
        this.pageId = pageId;
    }

    public Integer getOutputWay() {
        return outputWay;
    }

    public void setOutputWay(Integer outputWay) {
        this.outputWay = outputWay;
    }

    public Integer getNormalMode() {
        return normalMode;
    }

    public void setNormalMode(Integer normalMode) {
        this.normalMode = normalMode;
    }

    public Integer getSuperMode() {
        return superMode;
    }

    public void setSuperMode(Integer superMode) {
        this.superMode = superMode;
    }

    public Long getFirstGive() {
        return firstGive;
    }

    public void setFirstGive(Long firstGive) {
        this.firstGive = firstGive;
    }

    public Long getDailyGive() {
        return dailyGive;
    }

    public void setDailyGive(Long dailyGive) {
        this.dailyGive = dailyGive;
    }
}

==> activity-center-api-0.8.9.3-lqs20-20180419.021303-1-sources.jar: cn/com/duiba/tuia/activity/center/api/dto/ExtInfo.java <==
package cn.com.duiba.tuia.activity.center.api.dto;

import java.io.Serializable;

public class ExtInfo implements Serializable {

    private static final long serialVersionUID = -5922021485325753804L;
    /**
     * 现金奖励限制
     */
    private Integer cashLimit;

    /**
     * 积分奖励限制
     */
    private Integer integralLimit;
    /**
     * 每日拼图限制
     */
    private Integer timesLimit;
    /**
     * 拼图投放方式 如果为空或者为0代表小程序，1代表H5版本
     */
    private Integer outputWay;

    /**
     * 押注游戏-普通模式金额
     */
    private Integer normalMode;
    /**
     * 押注游戏-超级模式金额
     */
    private Integer superMode;

    private String ruleConfig;

    private Long pageId;

    /**
     * 首次登陆
     */
    private Long firstGive;

    /**
     * 每日登陆
     */
    private Long dailyGive;

    /**
     * 每日押注限制
     */
    private Long dailyLimit;

    public Integer getCashLimit() {
        return cashLimit;
    }

    public void setCashLimit(Integer cashLimit) {
        this.cashLimit = cashLimit;
    }

    public Integer getIntegralLimit() {
        return integralLimit;
    }

    public void setIntegralLimit(Integer integralLimit) {
        this.integralLimit = integralLimit;
    }

    public Integer getTimesLimit() {
        return timesLimit;
    }

    public void setTimesLimit(Integer timesLimit) {
        this.timesLimit = timesLimit;
    }

    public String getRuleConfig() {
        return ruleConfig;
    }

    public void setRuleConfig(String ruleConfig) {
        this.ruleConfig = ruleConfig;
    }

    public Long getPageId() {
        return pageId;
    }

    public void setPageId(Long pageId) {
        this.pageId = pageId;
    }

    public Integer getOutputWay() {
        return outputWay;
    }

    public void setOutputWay(Integer outputWay) {
        this.outputWay = outputWay;
    }

    public Integer getNormalMode() {
        return normalMode;
    }

    public void setNormalMode(Integer normalMode) {
        this.normalMode = normalMode;
    }

    public Integer getSuperMode() {
        return superMode;
    }

    public void setSuperMode(Integer superMode) {
        this.superMode = superMode;
    }

    public Long getFirstGive() {
        return firstGive;
    }

    public void setFirstGive(Long firstGive) {
        this.firstGive = firstGive;
    }

    public Long getDailyGive() {
        return dailyGive;
    }

    public void setDailyGive(Long dailyGive) {
        this.dailyGive = dailyGive;
    }

    public Long getDailyLimit() {
        return dailyLimit;
    }

    public void setDailyLimit(Long dailyLimit) {
        this.dailyLimit = dailyLimit;
    }
}
